==> jc-1.4.0.tar.gz: java/awt/AlphaComposite.h <==
// public final class java.awt.AlphaComposite

// class file dependencies
// @dep_class fd1c81a8e2f65605 java_awt_AlphaComposite
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_AlphaComposite_H_
#define _JC_java_awt_AlphaComposite_H_

// Forward structure declarations
struct _jc_java_awt_AlphaComposite$object;
struct _jc_java_awt_CompositeContext$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedHashMap$object;

// Typedefs
typedef struct _jc_java_awt_AlphaComposite$sub_refs	_jc_java_awt_AlphaComposite$sub_refs;
typedef struct _jc_java_awt_AlphaComposite$sub_nonrefs	_jc_java_awt_AlphaComposite$sub_nonrefs;
typedef struct _jc_java_awt_AlphaComposite$refs	_jc_java_awt_AlphaComposite$refs;
typedef struct _jc_java_awt_AlphaComposite$nonrefs	_jc_java_awt_AlphaComposite$nonrefs;
typedef struct _jc_java_awt_AlphaComposite$object	_jc_java_awt_AlphaComposite$object;

typedef struct _jc_java_awt_AlphaComposite$fields_struct	_jc_java_awt_AlphaComposite$fields_struct;
typedef const struct _jc_java_awt_AlphaComposite$vmethods	_jc_java_awt_AlphaComposite$vmethods;
typedef const struct _jc_java_awt_AlphaComposite$vtable	_jc_java_awt_AlphaComposite$vtable;
typedef const struct _jc_java_awt_AlphaComposite$vtype	_jc_java_awt_AlphaComposite$vtype;

// Class fields structure
struct _jc_java_awt_AlphaComposite$fields_struct {
	struct _jc_java_awt_AlphaComposite$object	*Clear;
	struct _jc_java_awt_AlphaComposite$object	*Dst;
	struct _jc_java_awt_AlphaComposite$object	*DstAtop;
	struct _jc_java_awt_AlphaComposite$object	*DstIn;
	struct _jc_java_awt_AlphaComposite$object	*DstOut;
	struct _jc_java_awt_AlphaComposite$object	*DstOver;
	struct _jc_java_awt_AlphaComposite$object	*Src;
	struct _jc_java_awt_AlphaComposite$object	*SrcAtop;
	struct _jc_java_awt_AlphaComposite$object	*SrcIn;
	struct _jc_java_awt_AlphaComposite$object	*SrcOut;
	struct _jc_java_awt_AlphaComposite$object	*SrcOver;
	struct _jc_java_awt_AlphaComposite$object	*Xor;
	struct _jc_java_util_LinkedHashMap$object	*cache;
	jint	CLEAR;
	jint	DST;
	jint	DST__5fATOP;
	jint	DST__5fIN;
	jint	DST__5fOUT;
	jint	DST__5fOVER;
	jint	SRC;
	jint	SRC__5fATOP;
	jint	SRC__5fIN;
	jint	SRC__5fOUT;
	jint	SRC__5fOVER;
	jint	XOR;
};
extern _jc_java_awt_AlphaComposite$fields_struct _jc_java_awt_AlphaComposite$class_fields;

// Constructors
extern void _jc_java_awt_AlphaComposite$method$_init$7cb044ce4fb0ada8(_jc_env *, struct _jc_java_awt_AlphaComposite$object *, jint, jfloat);

// Virtual methods
extern struct _jc_object *_jc_java_awt_AlphaComposite$method$createContext$f4115af9469e4273(_jc_env *, struct _jc_java_awt_AlphaComposite$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_RenderingHints$object *);
extern jboolean _jc_java_awt_AlphaComposite$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_AlphaComposite$object *, struct _jc_java_lang_Object$object *);
extern jfloat _jc_java_awt_AlphaComposite$method$getAlpha$520e5c5de58d5c07(_jc_env *, struct _jc_java_awt_AlphaComposite$object *);
extern jint _jc_java_awt_AlphaComposite$method$getRule$8a18bae7f257b744(_jc_env *, struct _jc_java_awt_AlphaComposite$object *);
extern jint _jc_java_awt_AlphaComposite$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_AlphaComposite$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_AlphaComposite$method_info$createContext$f4115af9469e4273;
extern _jc_method _jc_java_awt_AlphaComposite$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_AlphaComposite$method_info$getAlpha$520e5c5de58d5c07;
extern _jc_method _jc_java_awt_AlphaComposite$method_info$getRule$8a18bae7f257b744;
extern _jc_method _jc_java_awt_AlphaComposite$method_info$hashCode$53152098849316df;

// Static methods
extern void _jc_java_awt_AlphaComposite$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_awt_AlphaComposite$object *_jc_java_awt_AlphaComposite$method$getInstance$49e4177ff5c4d0e8(_jc_env *, jint);
extern struct _jc_java_awt_AlphaComposite$object *_jc_java_awt_AlphaComposite$method$getInstance$51937c783461494e(_jc_env *, jint, jfloat);

// Virtual methods structure
struct _jc_java_awt_AlphaComposite$vmethods {
	struct _jc_object	*(*createContext$f4115af9469e4273)(_jc_env *, struct _jc_java_awt_AlphaComposite$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_RenderingHints$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_AlphaComposite$object *, struct _jc_java_lang_Object$object *);
	jfloat	(*getAlpha$520e5c5de58d5c07)(_jc_env *, struct _jc_java_awt_AlphaComposite$object *);
	jint	(*getRule$8a18bae7f257b744)(_jc_env *, struct _jc_java_awt_AlphaComposite$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_AlphaComposite$object *);
};

// Vtable
struct _jc_java_awt_AlphaComposite$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AlphaComposite$vmethods	java_awt_AlphaComposite;
};

// Vtype
struct _jc_java_awt_AlphaComposite$vtype {
	_jc_type			type;
	_jc_java_awt_AlphaComposite$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AlphaComposite$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_AlphaComposite$refs {
    _jc_java_awt_AlphaComposite$sub_refs	java_awt_AlphaComposite;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AlphaComposite$sub_nonrefs {
	jint	rule;
	jfloat	alpha;
};

// Non-reference instance fields (object)
struct _jc_java_awt_AlphaComposite$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AlphaComposite$sub_nonrefs	java_awt_AlphaComposite;
};

// Object instance structure
struct _jc_java_awt_AlphaComposite$object {
	_jc_java_awt_AlphaComposite$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AlphaComposite$vtype	*vtype;
	_jc_java_awt_AlphaComposite$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AlphaComposite$vtype _jc_java_awt_AlphaComposite$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AlphaComposite, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AlphaComposite$class_object;

#endif	/* _JC_java_awt_AlphaComposite_H_ */

==> jc-1.4.6.tar.gz: java/awt/AlphaComposite.h <==
// public final class java.awt.AlphaComposite

// class file dependencies
// @dep_class fd1c81a8e2f65605 java_awt_AlphaComposite
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_AlphaComposite_H_
#define _JC_java_awt_AlphaComposite_H_

// Forward structure declarations
struct _jc_java_awt_AlphaComposite$object;
struct _jc_java_awt_CompositeContext$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedHashMap$object;

// Typedefs
typedef struct _jc_java_awt_AlphaComposite$sub_refs	_jc_java_awt_AlphaComposite$sub_refs;
typedef struct _jc_java_awt_AlphaComposite$sub_nonrefs	_jc_java_awt_AlphaComposite$sub_nonrefs;
typedef struct _jc_java_awt_AlphaComposite$refs	_jc_java_awt_AlphaComposite$refs;
typedef struct _jc_java_awt_AlphaComposite$nonrefs	_jc_java_awt_AlphaComposite$nonrefs;
typedef struct _jc_java_awt_AlphaComposite$object	_jc_java_awt_AlphaComposite$object;

typedef struct _jc_java_awt_AlphaComposite$fields_struct	_jc_java_awt_AlphaComposite$fields_struct;
typedef const struct _jc_java_awt_AlphaComposite$vmethods	_jc_java_awt_AlphaComposite$vmethods;
typedef const struct _jc_java_awt_AlphaComposite$vtable	_jc_java_awt_AlphaComposite$vtable;
typedef const struct _jc_java_awt_AlphaComposite$vtype	_jc_java_awt_AlphaComposite$vtype;

// Class fields structure
struct _jc_java_awt_AlphaComposite$fields_struct {
	struct _jc_java_awt_AlphaComposite$object	*Clear;
	struct _jc_java_awt_AlphaComposite$object	*Dst;
	struct _jc_java_awt_AlphaComposite$object	*DstAtop;
	struct _jc_java_awt_AlphaComposite$object	*DstIn;
	struct _jc_java_awt_AlphaComposite$object	*DstOut;
	struct _jc_java_awt_AlphaComposite$object	*DstOver;
	struct _jc_java_awt_AlphaComposite$object	*Src;
	struct _jc_java_awt_AlphaComposite$object	*SrcAtop;
	struct _jc_java_awt_AlphaComposite$object	*SrcIn;
	struct _jc_java_awt_AlphaComposite$object	*SrcOut;
	struct _jc_java_awt_AlphaComposite$object	*SrcOver;
	struct _jc_java_awt_AlphaComposite$object	*Xor;
	struct _jc_java_util_LinkedHashMap$object	*cache;
	jint	CLEAR;
	jint	DST;
	jint	DST__5fATOP;
	jint	DST__5fIN;
	jint	DST__5fOUT;
	jint	DST__5fOVER;
	jint	SRC;
	jint	SRC__5fATOP;
	jint	SRC__5fIN;
	jint	SRC__5fOUT;
	jint	SRC__5fOVER;
	jint	XOR;
};
extern _jc_java_awt_AlphaComposite$fields_struct _jc_java_awt_AlphaComposite$class_fields;

// Constructors
extern void _jc_java_awt_AlphaComposite$method$_init$7cb044ce4fb0ada8(_jc_env *, struct _jc_java_awt_AlphaComposite$object *, jint, jfloat) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_awt_AlphaComposite$method$createContext$f4115af9469e4273(_jc_env *, struct _jc_java_awt_AlphaComposite$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_RenderingHints$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_AlphaComposite$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_AlphaComposite$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jfloat _jc_java_awt_AlphaComposite$method$getAlpha$520e5c5de58d5c07(_jc_env *, struct _jc_java_awt_AlphaComposite$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_AlphaComposite$method$getRule$8a18bae7f257b744(_jc_env *, struct _jc_java_awt_AlphaComposite$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_AlphaComposite$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_awt_AlphaComposite$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_AlphaComposite$method_info$createContext$f4115af9469e4273;
extern _jc_method _jc_java_awt_AlphaComposite$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_AlphaComposite$method_info$getAlpha$520e5c5de58d5c07;
extern _jc_method _jc_java_awt_AlphaComposite$method_info$getRule$8a18bae7f257b744;
extern _jc_method _jc_java_awt_AlphaComposite$method_info$hashCode$53152098849316df;

// Static methods
extern void _jc_java_awt_AlphaComposite$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_AlphaComposite$object *_jc_java_awt_AlphaComposite$method$getInstance$49e4177ff5c4d0e8(_jc_env *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_awt_AlphaComposite$object *_jc_java_awt_AlphaComposite$method$getInstance$51937c783461494e(_jc_env *, jint, jfloat) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_AlphaComposite$vmethods {
	struct _jc_object	*(*createContext$f4115af9469e4273)(_jc_env *, struct _jc_java_awt_AlphaComposite$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_RenderingHints$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_AlphaComposite$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jfloat	(*getAlpha$520e5c5de58d5c07)(_jc_env *, struct _jc_java_awt_AlphaComposite$object *) _JC_JCNI_ATTR;
	jint	(*getRule$8a18bae7f257b744)(_jc_env *, struct _jc_java_awt_AlphaComposite$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_awt_AlphaComposite$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_AlphaComposite$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AlphaComposite$vmethods	java_awt_AlphaComposite;
};

// Vtype
struct _jc_java_awt_AlphaComposite$vtype {
	_jc_type			type;
	_jc_java_awt_AlphaComposite$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AlphaComposite$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_AlphaComposite$refs {
    _jc_java_awt_AlphaComposite$sub_refs	java_awt_AlphaComposite;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AlphaComposite$sub_nonrefs {
	jint	rule;
	jfloat	alpha;
};

// Non-reference instance fields (object)
struct _jc_java_awt_AlphaComposite$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AlphaComposite$sub_nonrefs	java_awt_AlphaComposite;
};

// Object instance structure
struct _jc_java_awt_AlphaComposite$object {
	_jc_java_awt_AlphaComposite$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AlphaComposite$vtype	*vtype;
	_jc_java_awt_AlphaComposite$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AlphaComposite$vtype _jc_java_awt_AlphaComposite$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AlphaComposite, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AlphaComposite$class_object;

#endif	/* _JC_java_awt_AlphaComposite_H_ */
